# Plugins

:::{index} Plugins
:::

Arelle provides an extensible interface for enabling new functionality.
Plugins are used for all kinds of things, from taxonomy specific validations, to building XBRL viewers.
Looking to build a new XBRL tool or application? An Arelle plugin is a good place to start.

:::{toctree}
:maxdepth: 2
installation
using_with_gui
using_with_cli
popular/popular_plugins
development/development
:::
